@@ -1,13 +1,13 @@
 package DBIx::Diff::Schema;
 
-our $DATE = '2015-01-07'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-04-24'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use List::Util qw(first);
 
@@ -16,6 +16,8 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
                        diff_db_schema
                        diff_table_schema
+                       db_schema_eq
+                       table_schema_eq
                );
 
 our %SPEC;
@@ -25,21 +27,48 @@ $SPEC{':package'} = {
     summary => 'Compare schema of two DBI databases',
 };
 
-my %common_args = (
+my %diff_db_args = (
     dbh1 => {
         schema => ['obj*'],
-        summary => 'DBI database handle for the first table',
+        summary => 'DBI database handle for the first database',
         req => 1,
         pos => 0,
     },
     dbh2 => {
         schema => ['obj*'],
-        summary => 'DBI database handle for the second table',
+        summary => 'DBI database handle for the second database',
         req => 1,
         pos => 1,
     },
 );
 
+my %diff_table_args = (
+    %diff_db_args,
+    table1 => {
+        schema => 'str*',
+        summary => 'Table name',
+        req => 1,
+        pos => 2,
+    },
+    table2 => {
+        schema => 'str*',
+        summary => 'Second table name (assumed to be the same as first table name if unspecified)',
+        pos => 3,
+    },
+);
+
+sub _check_table_exists {
+    my ($dbh, $name) = @_;
+    my $sth;
+    if ($name =~ /(.+)\.(.+)/) {
+        $sth = $dbh->table_info(undef, $1, $2, undef);
+    } else {
+        $sth = $dbh->table_info(undef, undef, $name, undef);
+    }
+
+    $sth->fetchrow_hashref ? 1:0;
+}
+
 sub _list_tables {
     my ($dbh) = @_;
 
@@ -110,6 +139,42 @@ sub _diff_column_schema {
     $res;
 }
 
+sub _diff_table_schema {
+    my ($dbh1, $dbh2, $table1, $table2) = @_;
+
+    my @columns1 = _list_columns($dbh1, $table1);
+    my @columns2 = _list_columns($dbh2, $table2);
+
+    $log->tracef("columns1: %s ...", \@columns1);
+    $log->tracef("columns2: %s ...", \@columns2);
+
+    my (@added, @deleted, %modified);
+    for my $c1 (@columns1) {
+        my $c1n = $c1->{COLUMN_NAME};
+        my $c2 = first {$c1n eq $_->{COLUMN_NAME}} @columns2;
+        if (defined $c2) {
+            my $tres = _diff_column_schema($c1, $c2);
+            $modified{$c1n} = $tres if %$tres;
+        } else {
+            push @deleted, $c1n;
+        }
+    }
+    for my $c2 (@columns2) {
+        my $c2n = $c2->{COLUMN_NAME};
+        my $c1 = first {$c2n eq $_->{COLUMN_NAME}} @columns1;
+        if (defined $c1) {
+        } else {
+            push @added, $c2n;
+        }
+    }
+
+    my $res = {};
+    $res->{added_columns}    = \@added    if @added;
+    $res->{deleted_columns}  = \@deleted  if @deleted;
+    $res->{modified_columns} = \%modified if %modified;
+    $res;
+}
+
 $SPEC{diff_table_schema} = {
     v => 1.1,
     summary => 'Compare schema of two DBI tables',
@@ -132,57 +197,48 @@ handles along with table name and this function will return a hash:
 
 _
     args => {
-        %common_args,
-        table => {
-            schema => 'str*',
-            name => 'str*',
-            summary => 'Table name',
-            req => 1,
-            pos => 2,
-        },
+        %diff_table_args,
     },
     args_as => "array",
     result_naked => 1,
     "x.perinci.sub.wrapper.disable_validate_args" => 1,
 };
 sub diff_table_schema {
-    my $dbh1    = shift; require Scalar::Util;my $_sahv_dpath = []; my $arg_err; ((defined($dbh1)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Required but not specified"),0)) && ((Scalar::Util::blessed($dbh1)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Not of type object"),0)); if ($arg_err) { die "diff_table_schema(): " . "Invalid argument value for dbh1: $arg_err" } # VALIDATE_ARG
+    my $dbh1    = shift; no warnings ('void');require Scalar::Util;my $_sahv_dpath = []; my $arg_err; ((defined($dbh1)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Required but not specified"),0)) && ((Scalar::Util::blessed($dbh1)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Not of type object"),0)); if ($arg_err) { die "diff_table_schema(): " . "Invalid argument value for dbh1: $arg_err" } # VALIDATE_ARG
     my $dbh2    = shift; ((defined($dbh2)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Required but not specified"),0)) && ((Scalar::Util::blessed($dbh2)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Not of type object"),0)); if ($arg_err) { die "diff_table_schema(): " . "Invalid argument value for dbh2: $arg_err" } # VALIDATE_ARG
-    my $table   = shift; ((defined($table)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Required but not specified"),0)) && ((!ref($table)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Not of type text"),0)); if ($arg_err) { die "diff_table_schema(): " . "Invalid argument value for table: $arg_err" } # VALIDATE_ARG
+    my $table1  = shift; ((defined($table1)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Required but not specified"),0)) && ((!ref($table1)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Not of type text"),0)); if ($arg_err) { die "diff_table_schema(): " . "Invalid argument value for table1: $arg_err" } # VALIDATE_ARG
+    my $table2  = shift // $table1; ((defined($table2)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Required but not specified"),0)) && ((!ref($table2)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Not of type text"),0)); if ($arg_err) { die "diff_table_schema(): " . "Invalid argument value for table2: $arg_err" } # VALIDATE_ARG
 
-    #$log->tracef("Comparing table %s ...", $table);
+    #$log->tracef("Comparing table %s vs %s ...", $table1, $table2);
 
-    my @columns1 = _list_columns($dbh1, $table);
-    my @columns2 = _list_columns($dbh2, $table);
+    die "Table $table1 in first database does not exist"
+        unless _check_table_exists($dbh1, $table1);
+    die "Table $table2 in second database does not exist"
+        unless _check_table_exists($dbh2, $table2);
+    _diff_table_schema($dbh1, $dbh2, $table1, $table2);
+}
 
-    #$log->tracef("columns1: %s ...", \@columns1);
-    #$log->tracef("columns2: %s ...", \@columns2);
+$SPEC{table_schema_eq} = {
+    v => 1.1,
+    summary => 'Return true if two DBI tables have the same schema',
+    description => <<'_',
 
-    my (@added, @deleted, %modified);
-    for my $c1 (@columns1) {
-        my $c1n = $c1->{COLUMN_NAME};
-        my $c2 = first {$c1n eq $_->{COLUMN_NAME}} @columns2;
-        if (defined $c2) {
-            my $tres = _diff_column_schema($c1, $c2);
-            $modified{$c1n} = $tres if keys %$tres;
-        } else {
-            push @deleted, $c1n;
-        }
-    }
-    for my $c2 (@columns2) {
-        my $c2n = $c2->{COLUMN_NAME};
-        my $c1 = first {$c2n eq $_->{COLUMN_NAME}} @columns1;
-        if (defined $c1) {
-        } else {
-            push @added, $c2n;
-        }
-    }
+This is basically just a shortcut for:
 
-    my $res = {};
-    $res->{added_columns}    = \@added    if @added;
-    $res->{deleted_columns}  = \@deleted  if @deleted;
-    $res->{modified_columns} = \%modified if keys %modified;
-    $res;
+    my $res = diff_table_schema(...);
+    !%res;
+
+_
+    args => {
+        %diff_table_args,
+    },
+    args_as => "array",
+    result_naked => 1,
+    "x.perinci.sub.wrapper.disable_validate_args" => 1,
+};
+sub table_schema_eq {
+    my $res = diff_table_schema(@_);
+    !%$res;
 }
 
 $SPEC{diff_db_schema} = {
@@ -218,14 +274,14 @@ database handles and this function will return a hash:
 
 _
     args => {
-        %common_args,
+        %diff_db_args,
     },
     args_as => "array",
     result_naked => 1,
     "x.perinci.sub.wrapper.disable_validate_args" => 1,
 };
 sub diff_db_schema {
-    my $dbh1 = shift; require Scalar::Util;my $_sahv_dpath = []; my $arg_err; ((defined($dbh1)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Required but not specified"),0)) && ((Scalar::Util::blessed($dbh1)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Not of type object"),0)); if ($arg_err) { die "diff_db_schema(): " . "Invalid argument value for dbh1: $arg_err" } # VALIDATE_ARG
+    my $dbh1 = shift; no warnings ('void');require Scalar::Util;my $_sahv_dpath = []; my $arg_err; ((defined($dbh1)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Required but not specified"),0)) && ((Scalar::Util::blessed($dbh1)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Not of type object"),0)); if ($arg_err) { die "diff_db_schema(): " . "Invalid argument value for dbh1: $arg_err" } # VALIDATE_ARG
     my $dbh2 = shift; ((defined($dbh2)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Required but not specified"),0)) && ((Scalar::Util::blessed($dbh2)) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Not of type object"),0)); if ($arg_err) { die "diff_db_schema(): " . "Invalid argument value for dbh2: $arg_err" } # VALIDATE_ARG
 
     my @tables1 = _list_tables($dbh1);
@@ -238,8 +294,8 @@ sub diff_db_schema {
     for (@tables1) {
         if ($_ ~~ @tables2) {
             #$log->tracef("Comparing table %s ...", $_);
-            my $tres = diff_table_schema($dbh1, $dbh2, $_);
-            $modified{$_} = $tres if keys %$tres;
+            my $tres = _diff_table_schema($dbh1, $dbh2, $_, $_);
+            $modified{$_} = $tres if %$tres;
         } else {
             push @deleted, $_;
         }
@@ -254,10 +310,33 @@ sub diff_db_schema {
     my $res = {};
     $res->{added_tables}    = \@added    if @added;
     $res->{deleted_tables}  = \@deleted  if @deleted;
-    $res->{modified_tables} = \%modified if keys %modified;
+    $res->{modified_tables} = \%modified if %modified;
     $res;
 }
 
+$SPEC{db_schema_eq} = {
+    v => 1.1,
+    summary => 'Return true if two DBI databases have the same schema',
+    description => <<'_',
+
+This is basically just a shortcut for:
+
+    my $res = diff_db_schema(...);
+    !%$res;
+
+_
+    args => {
+        %diff_db_args,
+    },
+    args_as => "array",
+    result_naked => 1,
+    "x.perinci.sub.wrapper.disable_validate_args" => 1,
+};
+sub db_schema_eq {
+    my $res = diff_db_schema(@_);
+    !%$res;
+}
+
 1;
 # ABSTRACT: Compare schema of two DBI databases
 
@@ -273,17 +352,22 @@ DBIx::Diff::Schema - Compare schema of two DBI databases
 
 =head1 VERSION
 
-This document describes version 0.04 of DBIx::Diff::Schema (from Perl distribution DBIx-Diff-Schema), released on 2015-01-07.
+This document describes version 0.05 of DBIx::Diff::Schema (from Perl distribution DBIx-Diff-Schema), released on 2015-04-24.
 
 =head1 SYNOPSIS
 
- use DBIx::Diff::Schema qw(diff_db_schema diff_table_schema);
+ use DBIx::Diff::Schema qw(diff_db_schema diff_table_schema
+                           db_schema_eq table_schema_eq);
 
- my $res  = diff_db_schema($dbh1, 'dbname1', $dbh2, 'dbname2');
+To compare schemas of whole databases:
 
-To compare schemas of a single table:
+ my $res = diff_db_schema($dbh1, $dbh2);
+ say "the two dbs are equal" if db_schema_eq($dbh1, $dbh2);
 
- my $res = diff_table_schema($dbh1, 'dbname1', $dbh2, 'dbname2', 'tablename');
+To compare schemas of a single table from two databases:
+
+ my $res = diff_table_schema($dbh1, $dbh2, 'tablename');
+ say "the two tables are equal" if table_schema_eq($dbh1, $dbh2, 'tablename');
 
 =head1 DESCRIPTION
 
@@ -292,6 +376,32 @@ Currently only tested on Postgres and SQLite.
 =head1 FUNCTIONS
 
 
+=head2 db_schema_eq($dbh1, $dbh2) -> any
+
+Return true if two DBI databases have the same schema.
+
+This is basically just a shortcut for:
+
+ my $res = diff_db_schema(...);
+ !%$res;
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<dbh1>* => I<obj>
+
+DBI database handle for the first database.
+
+=item * B<dbh2>* => I<obj>
+
+DBI database handle for the second database.
+
+=back
+
+Return value:  (any)
+
+
 =head2 diff_db_schema($dbh1, $dbh2) -> any
 
 Compare schemas of two DBI databases.
@@ -328,18 +438,18 @@ Arguments ('*' denotes required arguments):
 
 =item * B<dbh1>* => I<obj>
 
-DBI database handle for the first table.
+DBI database handle for the first database.
 
 =item * B<dbh2>* => I<obj>
 
-DBI database handle for the second table.
+DBI database handle for the second database.
 
 =back
 
 Return value:  (any)
 
 
-=head2 diff_table_schema($dbh1, $dbh2, $table) -> any
+=head2 diff_table_schema($dbh1, $dbh2, $table1, $table2) -> any
 
 Compare schema of two DBI tables.
 
@@ -364,16 +474,54 @@ Arguments ('*' denotes required arguments):
 
 =item * B<dbh1>* => I<obj>
 
-DBI database handle for the first table.
+DBI database handle for the first database.
 
 =item * B<dbh2>* => I<obj>
 
-DBI database handle for the second table.
+DBI database handle for the second database.
 
-=item * B<table>* => I<str>
+=item * B<table1>* => I<str>
 
 Table name.
 
+=item * B<table2> => I<str>
+
+Second table name (assumed to be the same as first table name if unspecified).
+
+=back
+
+Return value:  (any)
+
+
+=head2 table_schema_eq($dbh1, $dbh2, $table1, $table2) -> any
+
+Return true if two DBI tables have the same schema.
+
+This is basically just a shortcut for:
+
+ my $res = diff_table_schema(...);
+ !%res;
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<dbh1>* => I<obj>
+
+DBI database handle for the first database.
+
+=item * B<dbh2>* => I<obj>
+
+DBI database handle for the second database.
+
+=item * B<table1>* => I<str>
+
+Table name.
+
+=item * B<table2> => I<str>
+
+Second table name (assumed to be the same as first table name if unspecified).
+
 =back
 
 Return value:  (any)
